/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package opennlp.tools.langdetect;

/**
 * A data container encapsulating language detection results.
 *
 * @param languages The {@link Language languages} detected.
 * @param length    The length in codepoints of text processed.
 */
public record ProbingLanguageDetectionResult(Language[] languages, int length) {

  @Deprecated(forRemoval = true)
  public Language[] getLanguages() {
    return languages;
  }

  @Deprecated(forRemoval = true)
  public int getLength() {
    return length;
  }
}
